==> gradle-9.5.0-20260128005649+0000-src.zip: gradle-9.5.0-20260128005649+0000/platforms/core-configuration/declarative-dsl-provider/build.gradle.kts <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

plugins {
    id("gradlebuild.distribution.implementation-kotlin")
}

dependencies {
    api(projects.core)
    api(projects.coreApi)
    api(projects.declarativeDslApi)
    api(projects.declarativeDslCore)
    api(projects.declarativeDslEvaluator)
    api(projects.declarativeDslToolingModels)
    api(projects.serviceProvider)
    api(projects.projectFeatures)
    api(projects.stdlibJavaExtensions)

    api(libs.kotlinStdlib)
    api(libs.inject)

    implementation(projects.buildDiscoveryImpl)
    implementation(projects.concurrent)
    implementation(projects.baseServices)
    implementation(projects.modelCore)
    implementation(projects.messaging)
    implementation(projects.projectFeaturesApi)
    implementation(projects.resources)
    implementation(projects.serviceLookup)
    implementation(libs.guava)
    implementation(libs.kotlinReflect)
    implementation(libs.jspecify)

    testImplementation(libs.mockitoKotlin)
    testImplementation(testFixtures(projects.declarativeDslCore))
    testImplementation(testFixtures(projects.declarativeDslEvaluator))

    integTestImplementation(projects.internalTesting)
    integTestImplementation(projects.logging)
    integTestImplementation(testFixtures(projects.declarativeDslProvider))
    integTestImplementation(testFixtures(projects.toolingApi))

    testFixturesImplementation(projects.internalTesting)
    testFixturesImplementation(projects.internalIntegTesting)
    testFixturesImplementation(testFixtures(projects.declarativeDslCore))

    integTestDistributionRuntimeOnly(projects.distributionsFull)
}
tasks.isolatedProjectsIntegTest {
    enabled = false
}

==> gradle-9.5.0-20260201013059+0000-src.zip: gradle-9.5.0-20260201013059+0000/platforms/core-configuration/declarative-dsl-provider/build.gradle.kts <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

plugins {
    id("gradlebuild.distribution.implementation-kotlin")
}

dependencies {
    api(projects.core)
    api(projects.coreApi)
    api(projects.declarativeDslApi)
    api(projects.declarativeDslCore)
    api(projects.declarativeDslEvaluator)
    api(projects.declarativeDslToolingModels)
    api(projects.serviceProvider)
    api(projects.projectFeatures)
    api(projects.stdlibJavaExtensions)

    api(libs.kotlinStdlib)
    api(libs.inject)

    implementation(projects.buildDiscoveryImpl)
    implementation(projects.concurrent)
    implementation(projects.baseServices)
    implementation(projects.modelCore)
    implementation(projects.messaging)
    implementation(projects.projectFeaturesApi)
    implementation(projects.resources)
    implementation(projects.serviceLookup)
    implementation(libs.guava)
    implementation(libs.kotlinReflect)
    implementation(libs.jspecify)

    testImplementation(testLibs.mockitoKotlin)
    testImplementation(testFixtures(projects.declarativeDslCore))
    testImplementation(testFixtures(projects.declarativeDslEvaluator))

    integTestImplementation(projects.internalTesting)
    integTestImplementation(projects.logging)
    integTestImplementation(testFixtures(projects.declarativeDslProvider))
    integTestImplementation(testFixtures(projects.toolingApi))

    testFixturesImplementation(projects.internalTesting)
    testFixturesImplementation(projects.internalIntegTesting)
    testFixturesImplementation(testFixtures(projects.declarativeDslCore))

    integTestDistributionRuntimeOnly(projects.distributionsFull)
}
tasks.isolatedProjectsIntegTest {
    enabled = false
}
